@@ -13,7 +13,7 @@
 
 namespace Botan {
 
-class BOTAN_DLL AutoSeeded_RNG : public RandomNumberGenerator
+class AutoSeeded_RNG : public RandomNumberGenerator
    {
    public:
       void randomize(byte out[], size_t len) override
@@ -25,7 +25,12 @@ class BOTAN_DLL AutoSeeded_RNG : public RandomNumberGenerator
 
       std::string name() const override { return m_rng->name(); }
 
-      void reseed(size_t poll_bits = 256) override { m_rng->reseed(poll_bits); }
+      size_t reseed_with_sources(Entropy_Sources& srcs,
+                               size_t poll_bits,
+                               std::chrono::milliseconds poll_timeout) override
+         {
+         return m_rng->reseed_with_sources(srcs, poll_bits, poll_timeout);
+         }
 
       void add_entropy(const byte in[], size_t len) override
          { m_rng->add_entropy(in, len); }
